# Live Trading With AutoTrader

What use would backtesting be if you can't take the same strategy live? 
This is no concern when you use AutoTrader, which features a seamless 
transition from backtesting to livetrading. Simply run your
strategy through AutoTrader with `environment="live"`, and it will be live.
Simple as that.

## Live Trade Monitoring
AutoTrader also supports monitoring via Prometheus and Grafana. A template
dashboard can be found in the `templates` directory of the 
[AutoTrader repository](https://github.com/kieran-mackle/AutoTrader/tree/main/templates), and is previewed below.


```{image} ../assets/images/dashboard-light.png
:align: center
:class: only-light
```
```{image} ../assets/images/dashboard-dark.png
:align: center
:class: only-dark
```


## Supported Brokers
Check out the [supported brokers and exchanges](supported-brokers).
